@@ -271,7 +271,8 @@ register_setting(
     description=_("List of inline CSS styles that won't be stripped from "
         "``RichTextField`` instances."),
     editable=False,
-    default=(),
+    default=("margin-top", "margin-bottom", "margin-left", "margin-right",
+        "float", "vertical-align", "border", "margin"),
 )
 
 register_setting(
