@@ -176,8 +176,8 @@ def ifinstalled(parser, token):
 @register.render_tag
 def set_short_url_for(context, token):
     """
-    Sets the ``short_url`` attribute of the given model using the bit.ly
-    credentials if they have been specified and saves it.
+    Sets the ``short_url`` attribute of the given model using the
+    bit.ly credentials if they have been specified and saves it.
     """
     obj = context[token.split_contents()[1]]
     request = context["request"]
@@ -207,7 +207,8 @@ def gravatar_url(email, size=32):
 @register.to_end_tag
 def metablock(parsed):
     """
-    Remove HTML tags, entities and superfluous characters from meta blocks.
+    Remove HTML tags, entities and superfluous characters from
+    meta blocks.
     """
     parsed = " ".join(parsed.replace("\n", "").split()).replace(" ,", ",")
     return escape(strip_tags(decode_entities(parsed)))
@@ -237,11 +238,11 @@ def pagination_for(context, current_page, page_var="page", exclude_vars=""):
 @register.inclusion_tag("includes/search_form.html", takes_context=True)
 def search_form(context, search_model_names=None):
     """
-    Includes the search form with a list of models to use as choices for
-    filtering the search by. Models should be a string with models in the
-    format ``app_label.model_name`` separated by spaces. The string ``all``
-    can also be used, in which case the models defined by the
-    ``SEARCH_MODEL_CHOICES`` setting will be used.
+    Includes the search form with a list of models to use as choices
+    for filtering the search by. Models should be a string with models
+    in the format ``app_label.model_name`` separated by spaces. The
+    string ``all`` can also be used, in which case the models defined
+    by the ``SEARCH_MODEL_CHOICES`` setting will be used.
     """
     if not search_model_names:
         search_model_names = []
@@ -325,7 +326,7 @@ def thumbnail(image_url, width, height, quality=95):
     if image.mode not in ("P", "L", "RGBA"):
         image = image.convert("RGBA")
     # Required for progressive jpgs.
-    ImageFile.MAXBLOCK = image.size[0] * image.size[1]
+    ImageFile.MAXBLOCK = 2 * (max(image.size) ** 2)
     try:
         image = ImageOps.fit(image, (width, height), Image.ANTIALIAS)
         image = image.save(thumb_path, filetype, quality=quality, **image_info)
@@ -377,10 +378,11 @@ def richtext_filter(content):
 @register.to_end_tag
 def editable(parsed, context, token):
     """
-    Add the required HTML to the parsed content for in-line editing, such as
-    the icon and edit form if the object is deemed to be editable - either it
-    has an ``editable`` method which returns ``True``, or the logged in user
-    has change permissions for the model.
+    Add the required HTML to the parsed content for in-line editing,
+    such as the icon and edit form if the object is deemed to be
+    editable - either it has an ``editable`` method which returns
+    ``True``, or the logged in user has change permissions for the
+    model.
     """
     def parse_field(field):
         field = field.split(".")
@@ -413,9 +415,9 @@ def editable(parsed, context, token):
 @register.simple_tag
 def try_url(url_name):
     """
-    Mimics Django's ``url`` template tag but fails silently. Used for url
-    names in admin templates as these won't resolve when admin tests are
-    running.
+    Mimics Django's ``url`` template tag but fails silently. Used for
+    url names in admin templates as these won't resolve when admin
+    tests are running.
     """
     from warnings import warn
     warn("try_url is deprecated, use the url tag with the 'as' arg instead.")
@@ -428,8 +430,8 @@ def try_url(url_name):
 
 def admin_app_list(request):
     """
-    Adopted from ``django.contrib.admin.sites.AdminSite.index``. Returns a
-    list of lists of models grouped and ordered according to
+    Adopted from ``django.contrib.admin.sites.AdminSite.index``.
+    Returns a list of lists of models grouped and ordered according to
     ``mezzanine.conf.ADMIN_MENU_ORDER``. Called from the
     ``admin_dropdown_menu`` template tag as well as the ``app_list``
     dashboard widget.
@@ -563,7 +565,8 @@ def recent_actions(context):
 def dashboard_column(context, token):
     """
     Takes an index for retrieving the sequence of template tags from
-    ``mezzanine.conf.DASHBOARD_TAGS`` to render into the admin dashboard.
+    ``mezzanine.conf.DASHBOARD_TAGS`` to render into the admin
+    dashboard.
     """
     column_index = int(token.split_contents()[1])
     output = []
