@@ -2,7 +2,7 @@
 from collections import defaultdict
 
 from django.core.exceptions import ImproperlyConfigured
-from django.template import TemplateSyntaxError, Variable
+from django.template import Context, TemplateSyntaxError, Variable
 from django.template.loader import get_template
 from django.utils.translation import ugettext_lazy as _
 
@@ -127,7 +127,7 @@ def page_menu(context, token):
             context["page_branch_in_footer"] = True
 
     t = get_template(template_name)
-    return t.render(context)
+    return t.render(Context(context))
 
 
 @register.as_tag
